@@ -1,3 +1,3 @@
 from .authup import Authup
-from .schemas import Permission, TokenResponse, User
+from .schemas.user import User
 from .token import get_token, get_token_async
